@@ -145,6 +145,7 @@ class YOLO():
         self.ckpt_manager = None
         self.checkpoint = None
         self.colors = tf.constant([(253, 165, 15)], dtype=tf.float32) / 255.
+        self.loss = None
 
     def _list_to_dict(self):
         category_list = []
@@ -231,16 +232,27 @@ class YOLO():
 
         return self.feature_extractor
 
-    def compile(self, optimizer="adam", lr=1e-4, loss_scaling=False):
+    def compile(self,
+                optimizer="adam",
+                lr=1e-4,
+                loss="vanilla",
+                loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model.
 
         Args:
-            optimizer (str, optional): Optimizer. Defaults to "adam".
-            lr_gen (Float, optional): Learning rate generator. Defaults to 1e4.
-            lr_disc (Float, optional): Learning rate discriminator.
-                Defaults to 1e4.
+            optimizer: String. keras.optimizer. Defaults to "adam".
+            lr_gen: Float. Learning rate used by the generator. Defaults to 1e4.
+            lr_disc: Float. Learning rate used by the discriminator.
+                Defaults to 4e4.
+            loss: String. Choose between vanilla(v2.x) and ciou(v4) version.
+            loss_scaling: Boolean. Used with mixed precision.
         """
+        valid = {"vanilla", "ciou"}
+        if loss not in valid:
+            raise ValueError("loss mut be one of %r." % valid)
+        self.loss = loss
+
         if optimizer == "adadelta":
             self.optimizer = tf.keras.optimizers.Adadelta(lr)
         elif optimizer == "adagrad":
@@ -522,7 +534,8 @@ class YOLO():
                                  lambda_noobj,
                                  lambda_class,
                                  iou_threshold=iou_threshold,
-                                 step=step)
+                                 step=step,
+                                 version=self.loss)
 
             # Calculate gradient.
             gradient = tape.gradient(loss, self.model.trainable_variables)
