@@ -13,4 +13,4 @@
 # limitations under the License.
 # =============================================================================
 """Image detection models API"""
-from dnnlab.image_to_image.cnn import CNN
+from dnnlab.image_to_image.nn import NN
