@@ -227,7 +227,14 @@ class YOLODecoder(tf.keras.layers.Layer):
         # Direct location prediction!
         # bx = sig(tx) + cx <- Grid cell offset from top left
         # by = sig(ty) + cy <- Grid cell offset from top left
-        box_xy = tf.cast(tf.sigmoid(box_xy), dtype=tf.float32) + grid_coord
+        # YOLOv4: Grid Sensitivity!
+        # For cases bx = cx (sig(tx)->0) and bx = cx+1 (sig(tx)->1)tx needs to have
+        # huge neg or pos value multiplying with a scaling factor makes this easier
+        # -> PP-YOLO.
+        scale_x_y = 1.05
+        xy_grid_sensitiv = tf.cast(tf.sigmoid(box_xy), dtype=tf.float32) * \
+            scale_x_y - (scale_x_y-1)/2
+        box_xy = xy_grid_sensitiv + grid_coord
 
         # Unrestricted w, h values.
         box_wh = y_pred[..., 2:4]
